from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
import win32more.Windows.Win32.UI.Input.Radial
class IRadialControllerConfigurationInterop(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _iid_ = Guid('{787cdaac-3186-476d-87e4-b9374a7b9970}')
    @commethod(6)
    def GetForWindow(self, hwnd: win32more.Windows.Win32.Foundation.HWND, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRadialControllerIndependentInputSourceInterop(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _iid_ = Guid('{3d577eff-4cee-11e6-b535-001bdc06ab3b}')
    @commethod(6)
    def CreateForWindow(self, hwnd: win32more.Windows.Win32.Foundation.HWND, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRadialControllerInterop(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _iid_ = Guid('{1b0535c9-57ad-45c1-9d79-ad5c34360513}')
    @commethod(6)
    def CreateForWindow(self, hwnd: win32more.Windows.Win32.Foundation.HWND, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.UI.Shell.Common
PERCEIVEDFLAG_UNDEFINED: UInt32 = 0
PERCEIVEDFLAG_SOFTCODED: UInt32 = 1
PERCEIVEDFLAG_HARDCODED: UInt32 = 2
PERCEIVEDFLAG_NATIVESUPPORT: UInt32 = 4
PERCEIVEDFLAG_GDIPLUS: UInt32 = 16
PERCEIVEDFLAG_WMSDK: UInt32 = 32
PERCEIVEDFLAG_ZIPFOLDER: UInt32 = 64
class COMDLG_FILTERSPEC(Structure):
    pszName: win32more.Windows.Win32.Foundation.PWSTR
    pszSpec: win32more.Windows.Win32.Foundation.PWSTR
DEVICE_SCALE_FACTOR = Int32
DEVICE_SCALE_FACTOR_INVALID: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 0
SCALE_100_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 100
SCALE_120_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 120
SCALE_125_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 125
SCALE_140_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 140
SCALE_150_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 150
SCALE_160_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 160
SCALE_175_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 175
SCALE_180_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 180
SCALE_200_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 200
SCALE_225_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 225
SCALE_250_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 250
SCALE_300_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 300
SCALE_350_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 350
SCALE_400_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 400
SCALE_450_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 450
SCALE_500_PERCENT: win32more.Windows.Win32.UI.Shell.Common.DEVICE_SCALE_FACTOR = 500
class IObjectArray(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{92ca9dcd-5622-4bba-a805-5e9f541bd8c9}')
    @commethod(3)
    def GetCount(self, pcObjects: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetAt(self, uiIndex: UInt32, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IObjectCollection(ComPtr):
    extends: win32more.Windows.Win32.UI.Shell.Common.IObjectArray
    _iid_ = Guid('{5632b1a4-e38a-400a-928a-d4cd63230295}')
    @commethod(5)
    def AddObject(self, punk: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def AddFromArray(self, poaSource: win32more.Windows.Win32.UI.Shell.Common.IObjectArray) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RemoveObjectAt(self, uiIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ITEMIDLIST(Structure):
    mkid: win32more.Windows.Win32.UI.Shell.Common.SHITEMID
    _pack_ = 1
PERCEIVED = Int32
PERCEIVED_TYPE_FIRST: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = -3
PERCEIVED_TYPE_CUSTOM: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = -3
PERCEIVED_TYPE_UNSPECIFIED: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = -2
PERCEIVED_TYPE_FOLDER: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = -1
PERCEIVED_TYPE_UNKNOWN: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 0
PERCEIVED_TYPE_TEXT: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 1
PERCEIVED_TYPE_IMAGE: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 2
PERCEIVED_TYPE_AUDIO: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 3
PERCEIVED_TYPE_VIDEO: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 4
PERCEIVED_TYPE_COMPRESSED: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 5
PERCEIVED_TYPE_DOCUMENT: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 6
PERCEIVED_TYPE_SYSTEM: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 7
PERCEIVED_TYPE_APPLICATION: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 8
PERCEIVED_TYPE_GAMEMEDIA: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 9
PERCEIVED_TYPE_CONTACTS: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 10
PERCEIVED_TYPE_LAST: win32more.Windows.Win32.UI.Shell.Common.PERCEIVED = 10
SHCOLSTATE = Int32
SHCOLSTATE_DEFAULT: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 0
SHCOLSTATE_TYPE_STR: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 1
SHCOLSTATE_TYPE_INT: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 2
SHCOLSTATE_TYPE_DATE: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 3
SHCOLSTATE_TYPEMASK: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 15
SHCOLSTATE_ONBYDEFAULT: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 16
SHCOLSTATE_SLOW: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 32
SHCOLSTATE_EXTENDED: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 64
SHCOLSTATE_SECONDARYUI: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 128
SHCOLSTATE_HIDDEN: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 256
SHCOLSTATE_PREFER_VARCMP: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 512
SHCOLSTATE_PREFER_FMTCMP: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 1024
SHCOLSTATE_NOSORTBYFOLDERNESS: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 2048
SHCOLSTATE_VIEWONLY: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 65536
SHCOLSTATE_BATCHREAD: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 131072
SHCOLSTATE_NO_GROUPBY: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 262144
SHCOLSTATE_FIXED_WIDTH: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 4096
SHCOLSTATE_NODPISCALE: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 8192
SHCOLSTATE_FIXED_RATIO: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 16384
SHCOLSTATE_DISPLAYMASK: win32more.Windows.Win32.UI.Shell.Common.SHCOLSTATE = 61440
class SHELLDETAILS(Structure):
    fmt: Int32
    cxChar: Int32
    str: win32more.Windows.Win32.UI.Shell.Common.STRRET
    _pack_ = 1
class SHITEMID(Structure):
    cb: UInt16
    abID: Byte * 1
    _pack_ = 1
class STRRET(Structure):
    uType: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        pOleStr: win32more.Windows.Win32.Foundation.PWSTR
        uOffset: UInt32
        cStr: Byte * 260
STRRET_TYPE = Int32
STRRET_WSTR: win32more.Windows.Win32.UI.Shell.Common.STRRET_TYPE = 0
STRRET_OFFSET: win32more.Windows.Win32.UI.Shell.Common.STRRET_TYPE = 1
STRRET_CSTR: win32more.Windows.Win32.UI.Shell.Common.STRRET_TYPE = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices.Nfc
import win32more.Windows.Win32.Foundation
GUID_DEVINTERFACE_NFCDTA: Guid = Guid('{7fd3f30b-5e49-4be1-b3aa-af06260d236a}')
IOCTL_NFCDTA_CONFIG_RF_DISCOVERY: UInt32 = 2233344
IOCTL_NFCDTA_REMOTE_DEV_GET_NEXT: UInt32 = 2233348
IOCTL_NFCDTA_REMOTE_DEV_CONNECT: UInt32 = 2233352
IOCTL_NFCDTA_REMOTE_DEV_DISCONNECT: UInt32 = 2233356
IOCTL_NFCDTA_REMOTE_DEV_TRANSCEIVE: UInt32 = 2233360
IOCTL_NFCDTA_REMOTE_DEV_RECV: UInt32 = 2233364
IOCTL_NFCDTA_REMOTE_DEV_SEND: UInt32 = 2233368
IOCTL_NFCDTA_REMOTE_DEV_CHECK_PRESENCE: UInt32 = 2233372
IOCTL_NFCDTA_CONFIG_P2P_PARAM: UInt32 = 2233376
IOCTL_NFCDTA_SET_RF_CONFIG: UInt32 = 2233380
IOCTL_NFCDTA_REMOTE_DEV_NDEF_WRITE: UInt32 = 2233408
IOCTL_NFCDTA_REMOTE_DEV_NDEF_READ: UInt32 = 2233412
IOCTL_NFCDTA_REMOTE_DEV_NDEF_CONVERT_READ_ONLY: UInt32 = 2233416
IOCTL_NFCDTA_REMOTE_DEV_NDEF_CHECK: UInt32 = 2233420
IOCTL_NFCDTA_LLCP_CONFIG: UInt32 = 2233472
IOCTL_NFCDTA_LLCP_ACTIVATE: UInt32 = 2233476
IOCTL_NFCDTA_LLCP_DEACTIVATE: UInt32 = 2233480
IOCTL_NFCDTA_LLCP_DISCOVER_SERVICES: UInt32 = 2233484
IOCTL_NFCDTA_LLCP_LINK_STATUS_CHECK: UInt32 = 2233488
IOCTL_NFCDTA_LLCP_GET_NEXT_LINK_STATUS: UInt32 = 2233492
IOCTL_NFCDTA_LLCP_SOCKET_CREATE: UInt32 = 2233496
IOCTL_NFCDTA_LLCP_SOCKET_CLOSE: UInt32 = 2233500
IOCTL_NFCDTA_LLCP_SOCKET_BIND: UInt32 = 2233504
IOCTL_NFCDTA_LLCP_SOCKET_LISTEN: UInt32 = 2233508
IOCTL_NFCDTA_LLCP_SOCKET_ACCEPT: UInt32 = 2233512
IOCTL_NFCDTA_LLCP_SOCKET_CONNECT: UInt32 = 2233516
IOCTL_NFCDTA_LLCP_SOCKET_DISCONNECT: UInt32 = 2233520
IOCTL_NFCDTA_LLCP_SOCKET_RECV: UInt32 = 2233524
IOCTL_NFCDTA_LLCP_SOCKET_RECV_FROM: UInt32 = 2233528
IOCTL_NFCDTA_LLCP_SOCKET_SEND: UInt32 = 2233532
IOCTL_NFCDTA_LLCP_SOCKET_SNED_TO: UInt32 = 2233536
IOCTL_NFCDTA_LLCP_SOCKET_GET_NEXT_ERROR: UInt32 = 2233540
IOCTL_NFCDTA_SNEP_INIT_SERVER: UInt32 = 2233600
IOCTL_NFCDTA_SNEP_DEINIT_SERVER: UInt32 = 2233604
IOCTL_NFCDTA_SNEP_SERVER_GET_NEXT_CONNECTION: UInt32 = 2233608
IOCTL_NFCDTA_SNEP_SERVER_ACCEPT: UInt32 = 2233612
IOCTL_NFCDTA_SNEP_SERVER_GET_NEXT_REQUEST: UInt32 = 2233616
IOCTL_NFCDTA_SNEP_SERVER_SEND_RESPONSE: UInt32 = 2233620
IOCTL_NFCDTA_SNEP_INIT_CLIENT: UInt32 = 2233664
IOCTL_NFCDTA_SNEP_DEINIT_CLIENT: UInt32 = 2233668
IOCTL_NFCDTA_SNEP_CLIENT_PUT: UInt32 = 2233672
IOCTL_NFCDTA_SNEP_CLIENT_GET: UInt32 = 2233676
IOCTL_NFCDTA_SE_ENUMERATE: UInt32 = 2233728
IOCTL_NFCDTA_SE_SET_EMULATION_MODE: UInt32 = 2233732
IOCTL_NFCDTA_SE_SET_ROUTING_TABLE: UInt32 = 2233736
IOCTL_NFCDTA_SE_GET_NEXT_EVENT: UInt32 = 2233740
MAX_ATR_LENGTH: UInt32 = 48
MAX_UID_SIZE: UInt32 = 16
MAX_LLCP_SERVICE_NAME_SIZE: UInt32 = 256
MAX_SNEP_SERVER_NAME_SIZE: UInt32 = 256
GUID_NFC_RADIO_MEDIA_DEVICE_INTERFACE: Guid = Guid('{4d51e930-750d-4a36-a9f7-91dc540fcd30}')
GUID_NFCSE_RADIO_MEDIA_DEVICE_INTERFACE: Guid = Guid('{ef8ba08f-148d-4116-83ef-a2679dfc3fa5}')
NFCRMDDI_IOCTL_BASE: UInt32 = 80
IOCTL_NFCRM_SET_RADIO_STATE: UInt32 = 5308804
IOCTL_NFCRM_QUERY_RADIO_STATE: UInt32 = 5308808
IOCTL_NFCSERM_SET_RADIO_STATE: UInt32 = 5308812
IOCTL_NFCSERM_QUERY_RADIO_STATE: UInt32 = 5308816
GUID_DEVINTERFACE_NFCSE: Guid = Guid('{8dc7c854-f5e5-4bed-815d-0c85ad047725}')
IOCTL_NFCSE_ENUM_ENDPOINTS: UInt32 = 2230272
IOCTL_NFCSE_SUBSCRIBE_FOR_EVENT: UInt32 = 2230276
IOCTL_NFCSE_GET_NEXT_EVENT: UInt32 = 2230280
IOCTL_NFCSE_SET_CARD_EMULATION_MODE: UInt32 = 2230284
IOCTL_NFCSE_GET_NFCC_CAPABILITIES: UInt32 = 2230288
IOCTL_NFCSE_GET_ROUTING_TABLE: UInt32 = 2230292
IOCTL_NFCSE_SET_ROUTING_TABLE: UInt32 = 2230296
IOCTL_NFCSE_HCE_REMOTE_RECV: UInt32 = 2230592
IOCTL_NFCSE_HCE_REMOTE_SEND: UInt32 = 2230596
IOCTL_NFCSE_SET_POWER_MODE: UInt32 = 2230600
EVT_TRANSACTION_TAG_AID: UInt32 = 129
EVT_TRANSACTION_TAG_PARAMETERS: UInt32 = 130
EVT_TRANSACTION_PARAMETER_MAX_LEN: UInt32 = 255
ISO_7816_MINIMUM_AID_LENGTH: UInt32 = 5
ISO_7816_MAXIMUM_AID_LENGTH: UInt32 = 16
class NFCRM_RADIO_STATE(Structure):
    MediaRadioOn: win32more.Windows.Win32.Foundation.BOOLEAN
class NFCRM_SET_RADIO_STATE(Structure):
    SystemStateUpdate: win32more.Windows.Win32.Foundation.BOOLEAN
    MediaRadioOn: win32more.Windows.Win32.Foundation.BOOLEAN
class NFC_DATA_BUFFER(Structure):
    cbBuffer: UInt16
    pbBuffer: Byte * 1
NFC_DEVICE_TYPE = Int32
NfcType1Tag: win32more.Windows.Win32.Devices.Nfc.NFC_DEVICE_TYPE = 0
NfcType2Tag: win32more.Windows.Win32.Devices.Nfc.NFC_DEVICE_TYPE = 1
NfcType3Tag: win32more.Windows.Win32.Devices.Nfc.NFC_DEVICE_TYPE = 2
NfcType4Tag: win32more.Windows.Win32.Devices.Nfc.NFC_DEVICE_TYPE = 3
NfcIP1Target: win32more.Windows.Win32.Devices.Nfc.NFC_DEVICE_TYPE = 4
NfcIP1Initiator: win32more.Windows.Win32.Devices.Nfc.NFC_DEVICE_TYPE = 5
NfcReader: win32more.Windows.Win32.Devices.Nfc.NFC_DEVICE_TYPE = 6
class NFC_LLCP_CONFIG(Structure):
    uMIU: UInt16
    uWKS: UInt16
    bLTO: Byte
    bOptions: Byte
    fAutoActivate: win32more.Windows.Win32.Foundation.BOOLEAN
NFC_LLCP_LINK_STATUS = Int32
LinkActivated: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_LINK_STATUS = 0
LinkDeactivated: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_LINK_STATUS = 1
class NFC_LLCP_SERVICE_DISCOVER_REQUEST(Structure):
    hRemoteDev: IntPtr
    NumberOfEntries: UInt32
    ServiceNameEntries: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SERVICE_NAME_ENTRY * 1
class NFC_LLCP_SERVICE_DISCOVER_SAP(Structure):
    NumberOfEntries: UInt32
    SAPEntries: Byte * 1
class NFC_LLCP_SERVICE_NAME_ENTRY(Structure):
    cbServiceName: UInt32
    pbServiceName: Byte * 1
class NFC_LLCP_SOCKET_ACCEPT_INFO(Structure):
    hSocket: IntPtr
    sSocketOption: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_OPTION
class NFC_LLCP_SOCKET_CL_PAYLOAD(Structure):
    hSocket: IntPtr
    bSAP: Byte
    sPayload: win32more.Windows.Win32.Devices.Nfc.NFC_DATA_BUFFER
class NFC_LLCP_SOCKET_CONNECT_INFO(Structure):
    hRemoteDev: IntPtr
    hSocket: IntPtr
    eConnectType: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_CONNECT_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        bSAP: Byte
        sServiceName: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SERVICE_NAME_ENTRY
NFC_LLCP_SOCKET_CONNECT_TYPE = Int32
NfcConnectBySap: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_CONNECT_TYPE = 0
NfcConnectByUri: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_CONNECT_TYPE = 1
NFC_LLCP_SOCKET_ERROR = Int32
NfcLlcpErrorDisconnected: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_ERROR = 0
NfcLlcpErrorFrameRejected: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_ERROR = 1
NfcLlcpErrorBusyCondition: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_ERROR = 2
NfcLlcpErrorNotBusyCondition: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_ERROR = 3
class NFC_LLCP_SOCKET_ERROR_INFO(Structure):
    hSocket: IntPtr
    eSocketError: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_ERROR
class NFC_LLCP_SOCKET_INFO(Structure):
    eSocketType: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_TYPE
    sSocketOption: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_OPTION
class NFC_LLCP_SOCKET_OPTION(Structure):
    uMIUX: UInt16
    bRW: Byte
class NFC_LLCP_SOCKET_PAYLOAD(Structure):
    hSocket: IntPtr
    bSAP: Byte
    sPayload: win32more.Windows.Win32.Devices.Nfc.NFC_DATA_BUFFER
class NFC_LLCP_SOCKET_SERVICE_INFO(Structure):
    hSocket: IntPtr
    bSAP: Byte
    sServiceName: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SERVICE_NAME_ENTRY
NFC_LLCP_SOCKET_TYPE = Int32
ConnectionOriented: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_TYPE = 0
Connectionless: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_TYPE = 1
class NFC_NDEF_INFO(Structure):
    fIsNdefFormatted: win32more.Windows.Win32.Foundation.BOOLEAN
    fIsReadOnly: win32more.Windows.Win32.Foundation.BOOLEAN
    dwActualMessageLength: UInt32
    dwMaxMessageLength: UInt32
NFC_P2P_MODE = Int32
NfcDepDefault: win32more.Windows.Win32.Devices.Nfc.NFC_P2P_MODE = 0
NfcDepPoll: win32more.Windows.Win32.Devices.Nfc.NFC_P2P_MODE = 1
NfcDepListen: win32more.Windows.Win32.Devices.Nfc.NFC_P2P_MODE = 2
class NFC_P2P_PARAM_CONFIG(Structure):
    eP2pMode: win32more.Windows.Win32.Devices.Nfc.NFC_P2P_MODE
    cbGeneralBytes: Byte
    pbGeneralBytes: Byte * 48
NFC_RELEASE_TYPE = Int32
IdleMode: win32more.Windows.Win32.Devices.Nfc.NFC_RELEASE_TYPE = 0
SleepMode: win32more.Windows.Win32.Devices.Nfc.NFC_RELEASE_TYPE = 1
Discovery: win32more.Windows.Win32.Devices.Nfc.NFC_RELEASE_TYPE = 2
class NFC_REMOTE_DEVICE_DISCONNET(Structure):
    hRemoteDev: IntPtr
    eReleaseType: win32more.Windows.Win32.Devices.Nfc.NFC_RELEASE_TYPE
class NFC_REMOTE_DEV_INFO(Structure):
    hRemoteDev: IntPtr
    eType: win32more.Windows.Win32.Devices.Nfc.NFC_DEVICE_TYPE
    eRFTech: Byte
    eProtocol: Byte
    cbUid: Byte
    pbUid: Byte * 16
class NFC_REMOTE_DEV_RECV_INFO(Structure):
    hRemoteDev: IntPtr
    sRecvBuffer: win32more.Windows.Win32.Devices.Nfc.NFC_DATA_BUFFER
class NFC_REMOTE_DEV_SEND_INFO(Structure):
    hRemoteDev: IntPtr
    usTimeOut: UInt16
    sSendBuffer: win32more.Windows.Win32.Devices.Nfc.NFC_DATA_BUFFER
class NFC_RF_DISCOVERY_CONFIG(Structure):
    usTotalDuration: UInt16
    ulPollConfig: UInt32
    fDisableCardEmulation: win32more.Windows.Win32.Foundation.BOOLEAN
    ucNfcIPMode: Byte
    fNfcIPTgtModeDisable: win32more.Windows.Win32.Foundation.BOOLEAN
    ucNfcIPTgtMode: Byte
    ucNfcCEMode: Byte
    ucBailoutConfig: Byte
    ucSystemCode: Byte * 2
    ucRequestCode: Byte
    ucTimeSlotNumber: Byte
    eRfDiscoveryMode: win32more.Windows.Win32.Devices.Nfc.NFC_RF_DISCOVERY_MODE
NFC_RF_DISCOVERY_MODE = Int32
RfDiscoveryConfig: win32more.Windows.Win32.Devices.Nfc.NFC_RF_DISCOVERY_MODE = 0
RfDiscoveryStart: win32more.Windows.Win32.Devices.Nfc.NFC_RF_DISCOVERY_MODE = 1
RFDiscoveryResume: win32more.Windows.Win32.Devices.Nfc.NFC_RF_DISCOVERY_MODE = 2
class NFC_SE_AID_ROUTING_INFO(Structure):
    hSecureElement: IntPtr
    bPowerState: Byte
    cbAid: UInt32
    pbAid: Byte * 16
NFC_SE_EMULATION_MODE = Int32
EmulationDisabled: win32more.Windows.Win32.Devices.Nfc.NFC_SE_EMULATION_MODE = 0
EmulationEnabled: win32more.Windows.Win32.Devices.Nfc.NFC_SE_EMULATION_MODE = 1
class NFC_SE_EMULATION_MODE_INFO(Structure):
    hSecureElement: IntPtr
    eMode: win32more.Windows.Win32.Devices.Nfc.NFC_SE_EMULATION_MODE
class NFC_SE_EVENT_INFO(Structure):
    hSecureElement: IntPtr
    eEventType: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_EVENT_TYPE
    cbEventData: UInt32
    pbEventData: Byte * 1
class NFC_SE_INFO(Structure):
    hSecureElement: IntPtr
    eSecureElementType: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_TYPE
class NFC_SE_LIST(Structure):
    NumberOfEndpoints: UInt32
    EndpointList: win32more.Windows.Win32.Devices.Nfc.NFC_SE_INFO * 1
class NFC_SE_PROTO_ROUTING_INFO(Structure):
    hSecureElement: IntPtr
    bPowerState: Byte
    eRfProtocolType: Byte
class NFC_SE_ROUTING_TABLE(Structure):
    NumberOfEntries: UInt32
    TableEntries: win32more.Windows.Win32.Devices.Nfc.NFC_SE_ROUTING_TABLE_ENTRY * 1
class NFC_SE_ROUTING_TABLE_ENTRY(Structure):
    eRoutingType: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_ROUTING_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        TechRoutingInfo: win32more.Windows.Win32.Devices.Nfc.NFC_SE_TECH_ROUTING_INFO
        ProtoRoutingInfo: win32more.Windows.Win32.Devices.Nfc.NFC_SE_PROTO_ROUTING_INFO
        AidRoutingInfo: win32more.Windows.Win32.Devices.Nfc.NFC_SE_AID_ROUTING_INFO
class NFC_SE_TECH_ROUTING_INFO(Structure):
    hSecureElement: IntPtr
    bPowerState: Byte
    eRfTechType: Byte
class NFC_SNEP_CLIENT_GET_INFO(Structure):
    hSnepClient: IntPtr
    sGetPayload: win32more.Windows.Win32.Devices.Nfc.NFC_DATA_BUFFER
class NFC_SNEP_CLIENT_INFO(Structure):
    hRemoteDev: IntPtr
    eServerType: win32more.Windows.Win32.Devices.Nfc.NFC_SNEP_SERVER_TYPE
    sSocketOption: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_OPTION
    sService: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SERVICE_NAME_ENTRY
class NFC_SNEP_CLIENT_PUT_INFO(Structure):
    hSnepClient: IntPtr
    sPutPayload: win32more.Windows.Win32.Devices.Nfc.NFC_DATA_BUFFER
NFC_SNEP_REQUEST_TYPE = Int32
SnepRequestGet: win32more.Windows.Win32.Devices.Nfc.NFC_SNEP_REQUEST_TYPE = 0
SnepRequestPut: win32more.Windows.Win32.Devices.Nfc.NFC_SNEP_REQUEST_TYPE = 1
class NFC_SNEP_SERVER_ACCEPT_INFO(Structure):
    hSnepServer: IntPtr
    hConnection: IntPtr
    sSocketOption: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_OPTION
class NFC_SNEP_SERVER_INFO(Structure):
    eServerType: win32more.Windows.Win32.Devices.Nfc.NFC_SNEP_SERVER_TYPE
    sSocketOption: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SOCKET_OPTION
    usInboxSize: UInt16
    bSAP: Byte
    sService: win32more.Windows.Win32.Devices.Nfc.NFC_LLCP_SERVICE_NAME_ENTRY
class NFC_SNEP_SERVER_REQUEST(Structure):
    hSnepServer: IntPtr
    hConnection: IntPtr
    eRequestType: win32more.Windows.Win32.Devices.Nfc.NFC_SNEP_REQUEST_TYPE
    sRequestPayload: win32more.Windows.Win32.Devices.Nfc.NFC_DATA_BUFFER
class NFC_SNEP_SERVER_RESPONSE_INFO(Structure):
    hSnepServer: IntPtr
    hConnection: IntPtr
    dwResponseStatus: UInt32
    sResponsePayload: win32more.Windows.Win32.Devices.Nfc.NFC_DATA_BUFFER
NFC_SNEP_SERVER_TYPE = Int32
DefaultSnepServer: win32more.Windows.Win32.Devices.Nfc.NFC_SNEP_SERVER_TYPE = 0
ExtendedSnepServer: win32more.Windows.Win32.Devices.Nfc.NFC_SNEP_SERVER_TYPE = 1
class SECURE_ELEMENT_AID_ROUTING_INFO(Structure):
    guidSecureElementId: Guid
    cbAid: UInt32
    pbAid: Byte * 16
SECURE_ELEMENT_CARD_EMULATION_MODE = Int32
EmulationOff: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_CARD_EMULATION_MODE = 0
EmulationOnPowerIndependent: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_CARD_EMULATION_MODE = 1
EmulationOnPowerDependent: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_CARD_EMULATION_MODE = 2
EmulationStealthListen: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_CARD_EMULATION_MODE = 3
class SECURE_ELEMENT_ENDPOINT_INFO(Structure):
    guidSecureElementId: Guid
    eSecureElementType: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_TYPE
class SECURE_ELEMENT_ENDPOINT_LIST(Structure):
    NumberOfEndpoints: UInt32
    EndpointList: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_ENDPOINT_INFO * 1
class SECURE_ELEMENT_EVENT_INFO(Structure):
    guidSecureElementId: Guid
    eEventType: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_EVENT_TYPE
    cbEventData: UInt32
    pbEventData: Byte * 1
class SECURE_ELEMENT_EVENT_SUBSCRIPTION_INFO(Structure):
    guidSecureElementId: Guid
    eEventType: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_EVENT_TYPE
SECURE_ELEMENT_EVENT_TYPE = Int32
ExternalReaderArrival: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_EVENT_TYPE = 0
ExternalReaderDeparture: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_EVENT_TYPE = 1
ApplicationSelected: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_EVENT_TYPE = 2
Transaction: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_EVENT_TYPE = 3
HceActivated: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_EVENT_TYPE = 4
HceDeactivated: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_EVENT_TYPE = 5
ExternalFieldEnter: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_EVENT_TYPE = 6
ExternalFieldExit: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_EVENT_TYPE = 7
class SECURE_ELEMENT_HCE_ACTIVATION_PAYLOAD(Structure):
    bConnectionId: UInt16
    eRfTechType: Byte
    eRfProtocolType: Byte
class SECURE_ELEMENT_HCE_DATA_PACKET(Structure):
    bConnectionId: UInt16
    cbPayload: UInt16
    pbPayload: Byte * 1
class SECURE_ELEMENT_NFCC_CAPABILITIES(Structure):
    cbMaxRoutingTableSize: UInt16
    IsAidRoutingSupported: win32more.Windows.Win32.Foundation.BOOLEAN
    IsProtocolRoutingSupported: win32more.Windows.Win32.Foundation.BOOLEAN
    IsTechRoutingSupported: win32more.Windows.Win32.Foundation.BOOLEAN
SECURE_ELEMENT_POWER_MODE = Int32
SEPowerMode_ForceOn: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_POWER_MODE = 0
SEPowerMode_AllowOff: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_POWER_MODE = 1
class SECURE_ELEMENT_PROTO_ROUTING_INFO(Structure):
    guidSecureElementId: Guid
    eRfProtocolType: Byte
class SECURE_ELEMENT_ROUTING_TABLE(Structure):
    NumberOfEntries: UInt32
    TableEntries: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_ROUTING_TABLE_ENTRY * 1
class SECURE_ELEMENT_ROUTING_TABLE_ENTRY(Structure):
    eRoutingType: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_ROUTING_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        TechRoutingInfo: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_TECH_ROUTING_INFO
        ProtoRoutingInfo: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_PROTO_ROUTING_INFO
        AidRoutingInfo: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_AID_ROUTING_INFO
SECURE_ELEMENT_ROUTING_TYPE = Int32
RoutingTypeTech: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_ROUTING_TYPE = 0
RoutingTypeProtocol: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_ROUTING_TYPE = 1
RoutingTypeAid: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_ROUTING_TYPE = 2
class SECURE_ELEMENT_SET_CARD_EMULATION_MODE_INFO(Structure):
    guidSecureElementId: Guid
    eMode: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_CARD_EMULATION_MODE
class SECURE_ELEMENT_SET_POWER_MODE_INFO(Structure):
    guidSecureElementId: Guid
    powerMode: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_POWER_MODE
class SECURE_ELEMENT_TECH_ROUTING_INFO(Structure):
    guidSecureElementId: Guid
    eRfTechType: Byte
SECURE_ELEMENT_TYPE = Int32
Integrated: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_TYPE = 0
External: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_TYPE = 1
DeviceHost: win32more.Windows.Win32.Devices.Nfc.SECURE_ELEMENT_TYPE = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.PointOfService
import win32more.Windows.Devices.PointOfService.Provider
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics.Imaging
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class BarcodeScannerDisableScannerRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerDisableScannerRequest
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerDisableScannerRequest'
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerDisableScannerRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerDisableScannerRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerDisableScannerRequest2, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAndDescriptionAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerDisableScannerRequest2, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class BarcodeScannerDisableScannerRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerDisableScannerRequestEventArgs
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerDisableScannerRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerDisableScannerRequestEventArgs) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerDisableScannerRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerDisableScannerRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class BarcodeScannerEnableScannerRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerEnableScannerRequest
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerEnableScannerRequest'
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerEnableScannerRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerEnableScannerRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerEnableScannerRequest2, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAndDescriptionAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerEnableScannerRequest2, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class BarcodeScannerEnableScannerRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerEnableScannerRequestEventArgs
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerEnableScannerRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerEnableScannerRequestEventArgs) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerEnableScannerRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerEnableScannerRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class BarcodeScannerFrameReader(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerFrameReader
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReader'
    @winrt_mixinmethod
    def StartAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerFrameReader) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def StopAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerFrameReader) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def TryAcquireLatestFrameAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerFrameReader) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerVideoFrame]: ...
    @winrt_mixinmethod
    def get_Connection(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerFrameReader) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection: ...
    @winrt_mixinmethod
    def add_FrameArrived(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerFrameReader, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReader, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReaderFrameArrivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameArrived(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerFrameReader, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    Connection = property(get_Connection, None)
    FrameArrived = event()
class BarcodeScannerFrameReaderFrameArrivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerFrameReaderFrameArrivedEventArgs
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReaderFrameArrivedEventArgs'
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerFrameReaderFrameArrivedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
class BarcodeScannerGetSymbologyAttributesRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequest
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerGetSymbologyAttributesRequest'
    @winrt_mixinmethod
    def get_Symbology(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequest) -> UInt32: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequest, attributes: win32more.Windows.Devices.PointOfService.BarcodeSymbologyAttributes) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequest2, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAndDescriptionAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequest2, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    Symbology = property(get_Symbology, None)
class BarcodeScannerGetSymbologyAttributesRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequestEventArgs
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerGetSymbologyAttributesRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequestEventArgs) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerGetSymbologyAttributesRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class BarcodeScannerHideVideoPreviewRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerHideVideoPreviewRequest
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerHideVideoPreviewRequest'
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerHideVideoPreviewRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerHideVideoPreviewRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerHideVideoPreviewRequest2, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAndDescriptionAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerHideVideoPreviewRequest2, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class BarcodeScannerHideVideoPreviewRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerHideVideoPreviewRequestEventArgs
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerHideVideoPreviewRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerHideVideoPreviewRequestEventArgs) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerHideVideoPreviewRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerHideVideoPreviewRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class BarcodeScannerProviderConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_VideoDeviceId(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SupportedSymbologies(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection) -> win32more.Windows.Foundation.Collections.IVector[UInt32]: ...
    @winrt_mixinmethod
    def get_CompanyName(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CompanyName(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Name(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Version(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Version(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def Start(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection) -> Void: ...
    @winrt_mixinmethod
    def ReportScannedDataAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, report: win32more.Windows.Devices.PointOfService.BarcodeScannerReport) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportTriggerStateAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, state: win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerTriggerState) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportErrorAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, errorData: win32more.Windows.Devices.PointOfService.UnifiedPosErrorData) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportErrorAsyncWithScanReport(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, errorData: win32more.Windows.Devices.PointOfService.UnifiedPosErrorData, isRetriable: Boolean, scanReport: win32more.Windows.Devices.PointOfService.BarcodeScannerReport) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def add_EnableScannerRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerEnableScannerRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_EnableScannerRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DisableScannerRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerDisableScannerRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DisableScannerRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SetActiveSymbologiesRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerSetActiveSymbologiesRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SetActiveSymbologiesRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_StartSoftwareTriggerRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerStartSoftwareTriggerRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StartSoftwareTriggerRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_StopSoftwareTriggerRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerStopSoftwareTriggerRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StopSoftwareTriggerRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_GetBarcodeSymbologyAttributesRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerGetSymbologyAttributesRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_GetBarcodeSymbologyAttributesRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SetBarcodeSymbologyAttributesRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerSetSymbologyAttributesRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SetBarcodeSymbologyAttributesRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_HideVideoPreviewRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerHideVideoPreviewRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HideVideoPreviewRequested(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def CreateFrameReaderAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection2) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReader]: ...
    @winrt_mixinmethod
    def CreateFrameReaderWithFormatAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection2, preferredFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReader]: ...
    @winrt_mixinmethod
    def CreateFrameReaderWithFormatAndSizeAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection2, preferredFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, preferredSize: win32more.Windows.Graphics.Imaging.BitmapSize) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReader]: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    CompanyName = property(get_CompanyName, put_CompanyName)
    Id = property(get_Id, None)
    Name = property(get_Name, put_Name)
    SupportedSymbologies = property(get_SupportedSymbologies, None)
    Version = property(get_Version, put_Version)
    VideoDeviceId = property(get_VideoDeviceId, None)
    EnableScannerRequested = event()
    DisableScannerRequested = event()
    SetActiveSymbologiesRequested = event()
    StartSoftwareTriggerRequested = event()
    StopSoftwareTriggerRequested = event()
    GetBarcodeSymbologyAttributesRequested = event()
    SetBarcodeSymbologyAttributesRequested = event()
    HideVideoPreviewRequested = event()
class BarcodeScannerProviderTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderTriggerDetails
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerProviderTriggerDetails'
    @winrt_mixinmethod
    def get_Connection(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderTriggerDetails) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection: ...
    Connection = property(get_Connection, None)
class BarcodeScannerSetActiveSymbologiesRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequest
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerSetActiveSymbologiesRequest'
    @winrt_mixinmethod
    def get_Symbologies(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequest) -> win32more.Windows.Foundation.Collections.IVectorView[UInt32]: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequest2, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAndDescriptionAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequest2, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    Symbologies = property(get_Symbologies, None)
class BarcodeScannerSetActiveSymbologiesRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequestEventArgs
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerSetActiveSymbologiesRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequestEventArgs) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerSetActiveSymbologiesRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class BarcodeScannerSetSymbologyAttributesRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequest
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerSetSymbologyAttributesRequest'
    @winrt_mixinmethod
    def get_Symbology(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequest) -> UInt32: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequest) -> win32more.Windows.Devices.PointOfService.BarcodeSymbologyAttributes: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequest2, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAndDescriptionAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequest2, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    Attributes = property(get_Attributes, None)
    Symbology = property(get_Symbology, None)
class BarcodeScannerSetSymbologyAttributesRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequestEventArgs
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerSetSymbologyAttributesRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequestEventArgs) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerSetSymbologyAttributesRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class BarcodeScannerStartSoftwareTriggerRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStartSoftwareTriggerRequest
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerStartSoftwareTriggerRequest'
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStartSoftwareTriggerRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStartSoftwareTriggerRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStartSoftwareTriggerRequest2, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAndDescriptionAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStartSoftwareTriggerRequest2, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class BarcodeScannerStartSoftwareTriggerRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStartSoftwareTriggerRequestEventArgs
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerStartSoftwareTriggerRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStartSoftwareTriggerRequestEventArgs) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerStartSoftwareTriggerRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStartSoftwareTriggerRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class BarcodeScannerStopSoftwareTriggerRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStopSoftwareTriggerRequest
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerStopSoftwareTriggerRequest'
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStopSoftwareTriggerRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStopSoftwareTriggerRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStopSoftwareTriggerRequest2, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedWithFailedReasonAndDescriptionAsync(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStopSoftwareTriggerRequest2, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class BarcodeScannerStopSoftwareTriggerRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStopSoftwareTriggerRequestEventArgs
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerStopSoftwareTriggerRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStopSoftwareTriggerRequestEventArgs) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerStopSoftwareTriggerRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerStopSoftwareTriggerRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class BarcodeScannerTriggerState(Enum, Int32):
    Released = 0
    Pressed = 1
class BarcodeScannerVideoFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerVideoFrame
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeScannerVideoFrame'
    @winrt_mixinmethod
    def get_Format(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerVideoFrame) -> win32more.Windows.Graphics.Imaging.BitmapPixelFormat: ...
    @winrt_mixinmethod
    def get_Width(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerVideoFrame) -> UInt32: ...
    @winrt_mixinmethod
    def get_Height(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerVideoFrame) -> UInt32: ...
    @winrt_mixinmethod
    def get_PixelData(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeScannerVideoFrame) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    Format = property(get_Format, None)
    Height = property(get_Height, None)
    PixelData = property(get_PixelData, None)
    Width = property(get_Width, None)
class BarcodeSymbologyAttributesBuilder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.PointOfService.Provider.IBarcodeSymbologyAttributesBuilder
    _classid_ = 'Windows.Devices.PointOfService.Provider.BarcodeSymbologyAttributesBuilder'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Devices.PointOfService.Provider.BarcodeSymbologyAttributesBuilder.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeSymbologyAttributesBuilder: ...
    @winrt_mixinmethod
    def get_IsCheckDigitValidationSupported(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeSymbologyAttributesBuilder) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCheckDigitValidationSupported(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeSymbologyAttributesBuilder, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsCheckDigitTransmissionSupported(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeSymbologyAttributesBuilder) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsCheckDigitTransmissionSupported(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeSymbologyAttributesBuilder, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsDecodeLengthSupported(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeSymbologyAttributesBuilder) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDecodeLengthSupported(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeSymbologyAttributesBuilder, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def CreateAttributes(self: win32more.Windows.Devices.PointOfService.Provider.IBarcodeSymbologyAttributesBuilder) -> win32more.Windows.Devices.PointOfService.BarcodeSymbologyAttributes: ...
    IsCheckDigitTransmissionSupported = property(get_IsCheckDigitTransmissionSupported, put_IsCheckDigitTransmissionSupported)
    IsCheckDigitValidationSupported = property(get_IsCheckDigitValidationSupported, put_IsCheckDigitValidationSupported)
    IsDecodeLengthSupported = property(get_IsDecodeLengthSupported, put_IsDecodeLengthSupported)
class IBarcodeScannerDisableScannerRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerDisableScannerRequest'
    _iid_ = Guid('{88ecf7c0-37b9-4275-8e77-c8e52ae5a9c8}')
    @winrt_commethod(6)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerDisableScannerRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerDisableScannerRequest2'
    _iid_ = Guid('{ccdfe625-65c3-4ccc-b457-f39c7a9ea60d}')
    @winrt_commethod(6)
    def ReportFailedWithFailedReasonAsync(self, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedWithFailedReasonAndDescriptionAsync(self, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerDisableScannerRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerDisableScannerRequestEventArgs'
    _iid_ = Guid('{7006e142-e802-46f5-b604-352a15ce9232}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerDisableScannerRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IBarcodeScannerEnableScannerRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerEnableScannerRequest'
    _iid_ = Guid('{c0b3e9ba-816a-452b-bd77-b7e453ec446d}')
    @winrt_commethod(6)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerEnableScannerRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerEnableScannerRequest2'
    _iid_ = Guid('{71a4f2a8-9905-41ac-9121-b645916a84a1}')
    @winrt_commethod(6)
    def ReportFailedWithFailedReasonAsync(self, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedWithFailedReasonAndDescriptionAsync(self, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerEnableScannerRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerEnableScannerRequestEventArgs'
    _iid_ = Guid('{956c9419-7b4e-4451-8c41-8e10cfbc5b41}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerEnableScannerRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IBarcodeScannerFrameReader(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerFrameReader'
    _iid_ = Guid('{dbc72b07-64c3-482b-93c8-65fb33c22208}')
    @winrt_commethod(6)
    def StartAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(7)
    def StopAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def TryAcquireLatestFrameAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerVideoFrame]: ...
    @winrt_commethod(9)
    def get_Connection(self) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection: ...
    @winrt_commethod(10)
    def add_FrameArrived(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReader, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReaderFrameArrivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_FrameArrived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Connection = property(get_Connection, None)
    FrameArrived = event()
class IBarcodeScannerFrameReaderFrameArrivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerFrameReaderFrameArrivedEventArgs'
    _iid_ = Guid('{b0bbd604-54fd-436d-8629-712e787223dd}')
    @winrt_commethod(6)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
class IBarcodeScannerGetSymbologyAttributesRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequest'
    _iid_ = Guid('{9774c46a-58e4-4c5f-b8e9-e41467632700}')
    @winrt_commethod(6)
    def get_Symbology(self) -> UInt32: ...
    @winrt_commethod(7)
    def ReportCompletedAsync(self, attributes: win32more.Windows.Devices.PointOfService.BarcodeSymbologyAttributes) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    Symbology = property(get_Symbology, None)
class IBarcodeScannerGetSymbologyAttributesRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequest2'
    _iid_ = Guid('{6a6a2b13-75a8-49fb-b852-bfb93d760af7}')
    @winrt_commethod(6)
    def ReportFailedWithFailedReasonAsync(self, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedWithFailedReasonAndDescriptionAsync(self, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerGetSymbologyAttributesRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerGetSymbologyAttributesRequestEventArgs'
    _iid_ = Guid('{7f89de3e-fb5d-493c-b402-356b24d574a6}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerGetSymbologyAttributesRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IBarcodeScannerHideVideoPreviewRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerHideVideoPreviewRequest'
    _iid_ = Guid('{fa4ebe7f-6670-40e1-b90b-bb10d8d425fa}')
    @winrt_commethod(6)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerHideVideoPreviewRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerHideVideoPreviewRequest2'
    _iid_ = Guid('{7e28435d-9814-431d-a2f2-d6248c5ad4b5}')
    @winrt_commethod(6)
    def ReportFailedWithFailedReasonAsync(self, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedWithFailedReasonAndDescriptionAsync(self, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerHideVideoPreviewRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerHideVideoPreviewRequestEventArgs'
    _iid_ = Guid('{16a281fc-d6be-4bc7-9df1-33741f3eadea}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerHideVideoPreviewRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IBarcodeScannerProviderConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection'
    _iid_ = Guid('{b44acbed-0b3a-4fa3-86c5-491ea30780eb}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_VideoDeviceId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_SupportedSymbologies(self) -> win32more.Windows.Foundation.Collections.IVector[UInt32]: ...
    @winrt_commethod(9)
    def get_CompanyName(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def put_CompanyName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(11)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def put_Name(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(13)
    def get_Version(self) -> WinRT_String: ...
    @winrt_commethod(14)
    def put_Version(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(15)
    def Start(self) -> Void: ...
    @winrt_commethod(16)
    def ReportScannedDataAsync(self, report: win32more.Windows.Devices.PointOfService.BarcodeScannerReport) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(17)
    def ReportTriggerStateAsync(self, state: win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerTriggerState) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(18)
    def ReportErrorAsync(self, errorData: win32more.Windows.Devices.PointOfService.UnifiedPosErrorData) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(19)
    def ReportErrorAsyncWithScanReport(self, errorData: win32more.Windows.Devices.PointOfService.UnifiedPosErrorData, isRetriable: Boolean, scanReport: win32more.Windows.Devices.PointOfService.BarcodeScannerReport) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(20)
    def add_EnableScannerRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerEnableScannerRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_EnableScannerRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def add_DisableScannerRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerDisableScannerRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_DisableScannerRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def add_SetActiveSymbologiesRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerSetActiveSymbologiesRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(25)
    def remove_SetActiveSymbologiesRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(26)
    def add_StartSoftwareTriggerRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerStartSoftwareTriggerRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_StartSoftwareTriggerRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(28)
    def add_StopSoftwareTriggerRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerStopSoftwareTriggerRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(29)
    def remove_StopSoftwareTriggerRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(30)
    def add_GetBarcodeSymbologyAttributesRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerGetSymbologyAttributesRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_GetBarcodeSymbologyAttributesRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(32)
    def add_SetBarcodeSymbologyAttributesRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerSetSymbologyAttributesRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(33)
    def remove_SetBarcodeSymbologyAttributesRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(34)
    def add_HideVideoPreviewRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection, win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerHideVideoPreviewRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(35)
    def remove_HideVideoPreviewRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CompanyName = property(get_CompanyName, put_CompanyName)
    Id = property(get_Id, None)
    Name = property(get_Name, put_Name)
    SupportedSymbologies = property(get_SupportedSymbologies, None)
    Version = property(get_Version, put_Version)
    VideoDeviceId = property(get_VideoDeviceId, None)
    EnableScannerRequested = event()
    DisableScannerRequested = event()
    SetActiveSymbologiesRequested = event()
    StartSoftwareTriggerRequested = event()
    StopSoftwareTriggerRequested = event()
    GetBarcodeSymbologyAttributesRequested = event()
    SetBarcodeSymbologyAttributesRequested = event()
    HideVideoPreviewRequested = event()
class IBarcodeScannerProviderConnection2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderConnection2'
    _iid_ = Guid('{be9b53cd-1134-418c-a06b-04423a73f3d7}')
    @winrt_commethod(6)
    def CreateFrameReaderAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReader]: ...
    @winrt_commethod(7)
    def CreateFrameReaderWithFormatAsync(self, preferredFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReader]: ...
    @winrt_commethod(8)
    def CreateFrameReaderWithFormatAndSizeAsync(self, preferredFormat: win32more.Windows.Graphics.Imaging.BitmapPixelFormat, preferredSize: win32more.Windows.Graphics.Imaging.BitmapSize) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerFrameReader]: ...
class IBarcodeScannerProviderTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerProviderTriggerDetails'
    _iid_ = Guid('{50856d82-24e3-48ce-99c7-70aac1cbc9f7}')
    @winrt_commethod(6)
    def get_Connection(self) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerProviderConnection: ...
    Connection = property(get_Connection, None)
class IBarcodeScannerSetActiveSymbologiesRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequest'
    _iid_ = Guid('{db3f32b9-f7da-41a1-9f79-07bcd95f0bdf}')
    @winrt_commethod(6)
    def get_Symbologies(self) -> win32more.Windows.Foundation.Collections.IVectorView[UInt32]: ...
    @winrt_commethod(7)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    Symbologies = property(get_Symbologies, None)
class IBarcodeScannerSetActiveSymbologiesRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequest2'
    _iid_ = Guid('{f5ff6edf-fa9a-4749-b11b-e8fccb75bc6b}')
    @winrt_commethod(6)
    def ReportFailedWithFailedReasonAsync(self, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedWithFailedReasonAndDescriptionAsync(self, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerSetActiveSymbologiesRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerSetActiveSymbologiesRequestEventArgs'
    _iid_ = Guid('{06305afa-7bf6-4d52-801a-330272f60ae1}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerSetActiveSymbologiesRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IBarcodeScannerSetSymbologyAttributesRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequest'
    _iid_ = Guid('{32fb814f-a37f-48b0-acea-dce1480f12ae}')
    @winrt_commethod(6)
    def get_Symbology(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_Attributes(self) -> win32more.Windows.Devices.PointOfService.BarcodeSymbologyAttributes: ...
    @winrt_commethod(8)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    Attributes = property(get_Attributes, None)
    Symbology = property(get_Symbology, None)
class IBarcodeScannerSetSymbologyAttributesRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequest2'
    _iid_ = Guid('{dffbbfc1-dba8-4b77-be1e-b56cd72f65b3}')
    @winrt_commethod(6)
    def ReportFailedWithFailedReasonAsync(self, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedWithFailedReasonAndDescriptionAsync(self, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerSetSymbologyAttributesRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerSetSymbologyAttributesRequestEventArgs'
    _iid_ = Guid('{b2b89809-9824-47d4-85bd-d0077baa7bd2}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerSetSymbologyAttributesRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IBarcodeScannerStartSoftwareTriggerRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerStartSoftwareTriggerRequest'
    _iid_ = Guid('{e3fa7b27-ff62-4454-af4a-cb6144a3e3f7}')
    @winrt_commethod(6)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerStartSoftwareTriggerRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerStartSoftwareTriggerRequest2'
    _iid_ = Guid('{eb72a25c-6658-4765-a68e-327482653deb}')
    @winrt_commethod(6)
    def ReportFailedWithFailedReasonAsync(self, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedWithFailedReasonAndDescriptionAsync(self, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerStartSoftwareTriggerRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerStartSoftwareTriggerRequestEventArgs'
    _iid_ = Guid('{2305d843-c88f-4f3b-8c3b-d3df071051ec}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerStartSoftwareTriggerRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IBarcodeScannerStopSoftwareTriggerRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerStopSoftwareTriggerRequest'
    _iid_ = Guid('{6f9faf35-e287-4ca8-b70d-5a91d694f668}')
    @winrt_commethod(6)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerStopSoftwareTriggerRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerStopSoftwareTriggerRequest2'
    _iid_ = Guid('{cb57c5dd-fe50-49f8-a0b4-bdc230814da2}')
    @winrt_commethod(6)
    def ReportFailedWithFailedReasonAsync(self, reason: Int32) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ReportFailedWithFailedReasonAndDescriptionAsync(self, reason: Int32, failedReasonDescription: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
class IBarcodeScannerStopSoftwareTriggerRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerStopSoftwareTriggerRequestEventArgs'
    _iid_ = Guid('{eac34450-4eb7-481a-9273-147a273b99b8}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.Devices.PointOfService.Provider.BarcodeScannerStopSoftwareTriggerRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IBarcodeScannerVideoFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeScannerVideoFrame'
    _iid_ = Guid('{7e585248-9df7-4121-a175-801d8000112e}')
    @winrt_commethod(6)
    def get_Format(self) -> win32more.Windows.Graphics.Imaging.BitmapPixelFormat: ...
    @winrt_commethod(7)
    def get_Width(self) -> UInt32: ...
    @winrt_commethod(8)
    def get_Height(self) -> UInt32: ...
    @winrt_commethod(9)
    def get_PixelData(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    Format = property(get_Format, None)
    Height = property(get_Height, None)
    PixelData = property(get_PixelData, None)
    Width = property(get_Width, None)
class IBarcodeSymbologyAttributesBuilder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.PointOfService.Provider.IBarcodeSymbologyAttributesBuilder'
    _iid_ = Guid('{c57b0cbf-e4f5-40b9-84cf-e63fbaea42b4}')
    @winrt_commethod(6)
    def get_IsCheckDigitValidationSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsCheckDigitValidationSupported(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsCheckDigitTransmissionSupported(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsCheckDigitTransmissionSupported(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_IsDecodeLengthSupported(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsDecodeLengthSupported(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def CreateAttributes(self) -> win32more.Windows.Devices.PointOfService.BarcodeSymbologyAttributes: ...
    IsCheckDigitTransmissionSupported = property(get_IsCheckDigitTransmissionSupported, put_IsCheckDigitTransmissionSupported)
    IsCheckDigitValidationSupported = property(get_IsCheckDigitValidationSupported, put_IsCheckDigitValidationSupported)
    IsDecodeLengthSupported = property(get_IsDecodeLengthSupported, put_IsDecodeLengthSupported)


make_ready(__name__)
